"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolve = exports.Configuration = void 0;
const cosmiconfig_1 = __importDefault(require("cosmiconfig"));
const util_1 = __importDefault(require("util"));
const debug_1 = __importDefault(require("./debug"));
class Configuration {
    constructor(explicitValues) {
        this.explicitValues = explicitValues;
    }
    get globalStepDefinitions() {
        if (this.explicitValues.globalStepDefinitions === false) {
            return false;
        }
        return this.explicitValues.globalStepDefinitions || true;
    }
    get stepDefinitionsFolder() {
        if (this.explicitValues.stepDefinitionsFolder) {
            return this.explicitValues.stepDefinitionsFolder;
        }
        else if (this.globalStepDefinitions) {
            return "cypress/support/step_definitions";
        }
        else {
            return this.integrationFolder;
        }
    }
    get stepDefinitionsCommonFolder() {
        return this.explicitValues.stepDefinitionsCommonFolder || "common";
    }
    get integrationFolder() {
        return this.explicitValues.integrationFolder || "cypress/integration";
    }
}
exports.Configuration = Configuration;
async function resolve() {
    const result = await cosmiconfig_1.default("cypress-cucumber-preprocessor").load();
    if (result) {
        debug_1.default(`resolved configuration ${util_1.default.inspect(result.config)}`);
    }
    else {
        debug_1.default("resolved no configuration");
    }
    return new Configuration((result && result.config) || {});
}
exports.resolve = resolve;
