"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStepDefinitionDirectories = exports.getStepDefinitionPaths = void 0;
const path_1 = __importDefault(require("path"));
const glob_1 = __importDefault(require("glob"));
const util_1 = __importDefault(require("util"));
const is_path_inside_1 = __importDefault(require("is-path-inside"));
const debug_1 = __importDefault(require("./debug"));
const configuration_1 = require("./configuration");
async function getStepDefinitionPaths(filepath) {
    const configuration = await configuration_1.resolve();
    const patterns = getStepDefinitionDirectories(filepath, configuration).map((directory) => `${directory}/**/*.@(js|ts)`);
    debug_1.default(`looking for step definitions using ${patterns.join(", ")}`);
    const files = (await Promise.all(patterns.map((pattern) => util_1.default.promisify(glob_1.default)(pattern)))).reduce((acum, el) => acum.concat(el), []);
    if (files.length === 0) {
        debug_1.default("found no step definitions");
    }
    else {
        debug_1.default(`found step definitions in ${files.join(", ")}`);
    }
    return files;
}
exports.getStepDefinitionPaths = getStepDefinitionPaths;
function trimFeatureExtension(filepath) {
    return filepath.replace(/\.feature$/, "");
}
function getStepDefinitionDirectories(filepath, configuration, cwd = process.cwd()) {
    const fullIntegrationFolder = path_1.default.join(cwd, configuration.integrationFolder);
    if (!is_path_inside_1.default(filepath, fullIntegrationFolder)) {
        throw new Error(`${filepath} is not inside ${fullIntegrationFolder}`);
    }
    if (!is_path_inside_1.default(filepath, cwd)) {
        throw new Error(`${filepath} is not inside ${cwd}`);
    }
    if (configuration.globalStepDefinitions) {
        return [path_1.default.join(cwd, configuration.stepDefinitionsFolder)];
    }
    else {
        const relativeFilepath = path_1.default.relative(path_1.default.join(cwd, configuration.integrationFolder), filepath);
        return [
            path_1.default.join(cwd, configuration.stepDefinitionsFolder, trimFeatureExtension(relativeFilepath)),
            path_1.default.join(cwd, configuration.stepDefinitionsFolder, configuration.stepDefinitionsCommonFolder),
        ];
    }
}
exports.getStepDefinitionDirectories = getStepDefinitionDirectories;
