"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = __importDefault(require("util"));
const assert_1 = __importDefault(require("assert"));
const configuration_1 = require("./configuration");
const step_definitions_1 = require("./step-definitions");
function example(filepath, cwd, explicitValues, expected) {
    it(`should return [${expected.join(", ")}] for ${filepath} with ${util_1.default.inspect(explicitValues)} in ${cwd}`, () => {
        const actual = step_definitions_1.getStepDefinitionDirectories(filepath, new configuration_1.Configuration(explicitValues), cwd);
        const throwUnequal = () => {
            throw new Error(`Expected ${util_1.default.inspect(expected)}, but got ${util_1.default.inspect(actual)}`);
        };
        if (expected.length !== actual.length) {
            throwUnequal();
        }
        for (let i = 0; i < expected.length; i++) {
            if (expected[i] !== actual[i]) {
                throwUnequal();
            }
        }
    });
}
describe("getStepDefinitionDirectories()", () => {
    example("/foo/bar/cypress/integration/baz.feature", "/foo/bar", {}, [
        "/foo/bar/cypress/support/step_definitions",
    ]);
    example("/foo/bar/cypress/integration/baz.feature", "/foo/bar", { stepDefinitionsFolder: "cypress/integration/step_definitions" }, ["/foo/bar/cypress/integration/step_definitions"]);
    example("/foo/bar/cypress/integration/baz.feature", "/foo/bar", {
        globalStepDefinitions: false,
    }, ["/foo/bar/cypress/integration/baz", "/foo/bar/cypress/integration/common"]);
    example("/foo/bar/cypress/integration/baz.feature", "/foo/bar", {
        globalStepDefinitions: false,
        stepDefinitionsFolder: "cypress/support",
    }, ["/foo/bar/cypress/support/baz", "/foo/bar/cypress/support/common"]);
    example("/foo/bar/cypress/integration/baz.feature", "/foo/bar", {
        globalStepDefinitions: false,
        stepDefinitionsCommonFolder: "universal",
    }, [
        "/foo/bar/cypress/integration/baz",
        "/foo/bar/cypress/integration/universal",
    ]);
    example("/foo/bar/cypress/features/baz.feature", "/foo/bar", {
        globalStepDefinitions: false,
        integrationFolder: "cypress/features",
    }, ["/foo/bar/cypress/features/baz", "/foo/bar/cypress/features/common"]);
    it("should error when provided a path not within integrationFolder", () => {
        assert_1.default.throws(() => {
            step_definitions_1.getStepDefinitionDirectories("/foo/bar/cypress/features/baz.feature", new configuration_1.Configuration({}), "/foo/bar");
        }, "/foo/bar/cypress/features/baz.feature is not within cypress/integration");
    });
    it("should error when provided a path not within cwd", () => {
        assert_1.default.throws(() => {
            step_definitions_1.getStepDefinitionDirectories("/foo/bar/cypress/integration/baz.feature", new configuration_1.Configuration({}), "/baz");
        }, "/foo/bar/cypress/features/baz.feature is not within /baz");
    });
});
